###Marcelo A. Aizen, Gabriela R. Gleiser, Thomas Kitzberger, Ruben Milla. 
###Being a tree crop increases the odds of experiencing yield declines 
###irrespective of pollinator dependence. 

##################################################################################
#  Script to construct the main and supplementary figures. Run inVersion 4.0.2 of R #                      #
# Author: M.A. Aizen                                                             #
##################################################################################
options(max.print = 99999)
data=read.csv("growth.csv", sep=",", header=T) #dataset that includes growth rates estimates
data$dep<- factor(data$dep, levels = c( "none", "moderate", "high"))
data$slope_bin=ifelse(data$slope<0, 1, 0) #Converting yield growth into a binary variable
#decline 1 non-decline 0
data$lareac=log10(data$areac)-mean(log10(data$areac))  #log transfomation and centering of cumulative cultivated area per crop
data$lareap=log10(data$areap)-mean(log10(data$areap))  #log transfomation and centering of cumulative cultivated area per country

#Required packages
library(glmmTMB)
library(lme4)
library(arm)
library(lsmeans)
library(car)


options(max.print = 99999)
data=read.csv("growth.csv", sep=",", header=T) #dataset that includes growth rates estimates
data$dep<- factor(data$dep, levels = c( "none", "moderate", "high"))
data$slope_bin=ifelse(data$slope<0, 1, 0) #Converting yield growth into a binary variable
#decline 1 non-decline 0
data$lareac=log10(data$areac)-mean(log10(data$areac))  #log transfomation and centering of cumulative cultivated area per crop
data$lareap=log10(data$areap)-mean(log10(data$areap))  #log transfomation and centering of cumulative cultivated area per country

#Required packages
library(glmmTMB)
library(lme4)
library(arm)
library(lsmeans)
library(car)



############################Main figures################################

########################################################################################################
#Fig. 1.  Relative frequency of year of maximum yield for  4270 crop x country yield trends (1961-2020)
########################################################################################################

par(mfrow=c(2,1))
par(mar=c(0.2,4,2.8,4))
length(data$year_max[data$slope_bin==0])
h=hist(data$year_max[data$slope_bin==0] , plot=F,  breaks=70)
h$counts = 100*h$counts / sum(h$counts)
plot(h , main="" , xlim=c(1960,2020), ylab="",
     xlab="", ylim=c(0,20) , xaxt="n", las=1 , col="slateblue1", border=F, cex.axis=.7)
clip(1960,2020,0,20)
abline(v = median(data$year_max[data$slope_bin==0]), col="black", lwd=1, lty=2)
legend("topleft", legend=expression(paste("+ ", Delta, "yield (", italic("n"), "=3306)")),cex=.8, x.intersp=.6,
       fill=c("slateblue1"), border=F, bty="n")
par(mar=c(4.5,4,0.5,4))
length(data$year_max[data$slope_bin==1])
h=hist(data$year_max[data$slope_bin==1] , plot=F,  breaks=60)
h$counts =100*h$counts / sum(h$counts)
plot(h , main="" , xlim=c(1960,2020), ylab="",
     ylim=c(10,0) ,  xlab="", las=2 , col="tomato3", border=F, cex.axis=.8)
clip(1960,2020,0,10)
abline(v = median(data$year_max[data$slope_bin==1]), col="black", lwd=1, lty=2)
legend(1987, 8.5, legend=expression(paste("- ", Delta, "yield (", italic("n"), "=964)")),cex=.8, x.intersp=.6,
       fill=c("tomato3"), border=F, bty="n")

mtext("Year of maximum yield", side = 1, outer = TRUE, cex = .9, line = -2.0, adj=.5, col = "grey20")
mtext("Frequency (%)", side = 2, outer = TRUE, cex = .9 , adj=.5, line = -2.2, col = "grey20")


########################################################################################################
#Fig. 2.   World map of yield decline.
########################################################################################################

glmm_0=glmer(slope_bin ~ 1 +  (1|country) + (1|crop), data=data,  family=binomial)
x=coef(glmm_0)$country
y=rownames(x)
dec_count=data.frame(y, invlogit(x))
rownames(dec_count)=1:nrow(dec_count)
names(dec_count)=c("country", "dec")
dec_count$country[dec_count$country=="Cte d'Ivoire"]="Ivory Coast"
dec_count$country[dec_count$country=="China, Taiwan Province of"]="Taiwan"
dec_count$country[dec_count$country=="Eswatini"]="Swaziland"
dec_count$country[dec_count$country=="Cabo Verde"]="Cape Verde"
dec_count$dec[dec_count$country=="Trinidad and Tobago"]=0.59

library(rworldmap)
mapdep= joinCountryData2Map(dec_count,joinCode = "NAME"
                            ,nameJoinColumn = "country", verbose=TRUE)
library(rgdal)

#transform to robin for the Robinson projection
mapdep = spTransform(mapdep, CRS=CRS("+proj=robin +ellps=WGS84"))

mapParams=mapCountryData(mapdep
                         ,nameColumnToPlot='dec', mapTitle=""
                         ,  colourPalette = "heat", missingCountryCol="lightgrey" 
                         , catMethod=c(0, .10, .20, .30, .40, .50, .60), addLegend= 'FALSE')

do.call( addMapLegend, c( mapParams
                          , legendLabels="all"
                          , legendIntervals="data"
                          , legendWidth=0.5, legendShrink=0.5, labelFontSize=.8))


########################################################################################################
#Fig. 3. Relative frequency of crops with none, modest, and high dependence on pollinators across growth-form categories
########################################################################################################

xx=data.frame(data$crop, data$form, data$dep)
xx=unique(xx)
names(xx)=c("crop", "form", "dep")
xx=table(xx$dep, xx$form)
xx=apply(xx,2,function(x) 100*x/sum(x))

par(mar=c(5, 6, 4, 10.5), xpd=TRUE)
barplot(xx[,1:3], names.arg = c("Herb (79)", "Shrub (16)", "Tree (41)"), yaxt="n",
        cex.names = 1.2, ylab=" ", las=1, col=c("yellow", "orange", "red"))
title(xlab = "Growth form", line = 3, cex.lab=1.3) 
title(ylab = "Relative frequency (%)", line = 3, cex.lab=1.3) ## need to plot the axis label
axis(2,seq(0, 100,10), las=2, cex.lab=1.1)# , 
legend("topright", inset=c(-0.54, 0), legend=c("None","Modest",  "High"),
       cex=1.1, fill=c("yellow", "orange", "red"), title=expression(bold( "              Pollinator dependence")), bty="n")


########################################################################################################
# Fig. 4.  Probability  of yield decline in relation to pollinator dependence and growth form. 
########################################################################################################

glmm_1a=glmmTMB(slope_bin  ~   dep + region +   lareap + lareac  +  (1|country) + (1|crop), data=data,family=binomial(link="logit"))
Anova(glmm_1a)
glmm_1b=glmmTMB(slope_bin  ~   form + region +   lareap + lareac  +  (1|country) + (1|crop), data=data,family=binomial(link="logit"))
Anova(glmm_1b)
glmm_2 =glmmTMB(slope_bin  ~  dep +  form + region + lareap + lareac  +  (1|country) + (1|crop), data=data,family=binomial(link="logit"))
Anova(glmm_2)

par(mfrow = c(2, 2))
par(cex = 0.6)   #number indicating the amount by which plotting text and symbols 
#should be scaled relative to the default. 1=default, 1.5 is 50% larger, 0.5 is 50% smaller, etc.
par(oma = c(8,2 , 4, 2))  #internal margins, oma=external margins
par(tcl = -0.25)   #The length of tick marks as a fraction of the height of a line of text. 
#The default value is -0.5; setting tcl = NA sets tck = -0.01 which is S' default
par(mgp = c(3, 1, 0)) #The margin line (in mex units) for the axis title, axis labels 
#and axis line. Note that mgp[1] affects title whereas mgp[2:3] affect axis. The default is c(3, 1, 0).

colo1=c("yellow", "orange", "red")
colo2=c("chartreuse1", "darkolivegreen", "brown")

#..........................................................
par(mar = c(5,4,5,1)) 
plot(1, axes = FALSE, type = "n", xlim=c(-0.5, 2.5), ylim=c(0.1,.4), ylab="", xlab="")
box(col = "black") 
title(xlab="Pollinator dependence", cex.lab=1.3, line=3)
title(ylab="Probability of yield decline", cex.lab=1.3, line=3)
axis(1,  at = seq(0, 2, 1), labels = c("None", "Modest", "High"),
     cex.axis=1.1, tick = TRUE, las=1)
axis(2,  at = seq(0.1, .4, .05), labels = TRUE, tick = TRUE, las=2, cex.axis=1)

meansxx<-lsmeans(glmm_1a, ~ dep)
contrast(meansxx, alpha=0.05, method="pairwise", adjust="Tukey")
let=c("a", "a", "b")
(meansxx=summary(meansxx))
(means.es=invlogit(meansxx[,2]))
(means.lo=invlogit(meansxx[,2]-meansxx[,3]))
(means.hi=invlogit(meansxx[,2]+meansxx[,3]))

for (i in 1:3)
{
  arrows(i-1, means.lo[i], i-1,  means.hi[i], length=0, lwd=1.2, 
         angle=90, code=0 )
  points(i-1,means.es[i], pch=21,  cex=1.4,col="black", bg=colo1[i])
  text(i-1,  means.hi[i]+.02, cex=1.1, labels=let[i]) #, pos=4)
} 

mtext(expression("GLMM_1a"), side = 3, line = -1.2, adj = 0.1, cex = .6, col = "black")  
mtext(expression(paste(italic (X)[2]^2, "=6.71, ", italic (P), "=0.035")), side = 1, line = -1.2, adj =.9, cex = .6, col = "black")  


#..........................................................
par(mar = c(5,1,5,4)) 
plot(2, axes = FALSE, type = "n", xlim=c(-0.5, 2.5), ylim=c(0.1,.4), ylab="", xlab="")

box(col = "black") 
title(xlab="Pollinator dependence", cex.lab=1.3, line=2.8)
axis(1,  at = seq(0, 2, 1), labels = c("None", "Modest", "High"),
     cex.axis=1.1, tick = TRUE, las=1)
axis(2,  at = seq(0.1, .4, .05), labels = F, tick = TRUE, las=2, cex.axis=1)


meansxx<-lsmeans(glmm_2, ~ dep)
contrast(meansxx, alpha=0.05, method="pairwise", adjust="Tukey")
let=c("a", "a", "a")
(meansxx=summary(meansxx))
(means.es=invlogit(meansxx[,2]))
(means.lo=invlogit(meansxx[,2]-meansxx[,3]))
(means.hi=invlogit(meansxx[,2]+meansxx[,3]))


for (i in 1:3)
{
  arrows(i-1, means.lo[i], i-1,  means.hi[i], length=0, lwd=1.2, 
         angle=90, code=0 )
  points(i-1,means.es[i], pch=21,  cex=1.4,col="black", bg=colo1[i])
  text(i-1,  means.hi[i]+.02, cex=1.1, labels=let[i])
} 

mtext(expression("GLMM_2"), side = 3, line = -1.2, adj = 0.1, cex = .6, col = "black")  
mtext(expression(paste(italic (X)[2]^2, "=2.54 ", italic (P), "=0.28")), side = 1, line = -1.2, adj =.9, cex = .6, col = "black")  

#..........................................................
par(mar = c(7,4,3,1)) 

plot(3, axes = FALSE, type = "n", xlim=c(-0.5, 2.5), ylim=c(0.1,.4), ylab="", xlab="")
box(col = "black") 
title(xlab="Growth form", cex.lab=1.3, line=3)
title(ylab="Probability of yield decline", cex.lab=1.3, line=3)
axis(1,  at = seq(0, 2, 1), labels = c("Herb", "Shrub", "Tree"),
     cex.axis=1.1, tick = TRUE, las=1)
axis(2,  at = seq(0.1, .4, .05), labels = TRUE, tick = TRUE, las=2, cex.axis=1)

meansxx<-lsmeans(glmm_1b, ~ form)
contrast(meansxx, alpha=0.05, method="pairwise", adjust="Tukey")
let=c("a", "a", "b")
(meansxx=summary(meansxx))
(means.es=invlogit(meansxx[,2]))
(means.lo=invlogit(meansxx[,2]-meansxx[,3]))
(means.hi=invlogit(meansxx[,2]+meansxx[,3]))

for (i in 1:3)
{
  arrows(i-1, means.lo[i], i-1,  means.hi[i], length=0, lwd=1.2, 
         angle=90, code=0 )
  points(i-1,means.es[i], pch=21,  cex=1.4,col="black", bg=colo2[i])
  text(i-1,  means.hi[i]+.02, cex=1.1, labels=let[i])
} 

mtext(expression("GLMM_1b"), side = 3, line = -1.2, adj = 0.1, cex = .6, col = "black")  
mtext(expression(paste(italic (X)[2]^2, "=15.95, ", italic (P), "<0.0005")), side = 1, line = -1.2, adj =.9, cex = .6, col = "black")  

#..........................................................
par(mar = c(7,1,3,4)) 

plot(4, axes = FALSE, type = "n", xlim=c(-0.5, 2.5), ylim=c(0.1,.4), ylab="", xlab="")
box(col = "black") 
title(xlab="Growth form", cex.lab=1.3, line=3)

axis(1,  at = seq(0, 2, 1), labels = c("Herb", "Shrub", "Tree"),
     cex.axis=1.1, tick = TRUE, las=1)
axis(2,  at = seq(0.1, .4, .05), labels = F, tick = TRUE, las=2, cex.axis=1)

meansxx<-lsmeans(glmm_2, ~ form)
contrast(meansxx, alpha=0.05, method="pairwise", adjust="Tukey")
let=c("a", "a", "b")
(meansxx=summary(meansxx))
(means.es=invlogit(meansxx[,2]))
(means.lo=invlogit(meansxx[,2]-meansxx[,3]))
(means.hi=invlogit(meansxx[,2]+meansxx[,3]))

for (i in 1:3)
{
  arrows(i-1, means.lo[i], i-1,  means.hi[i], length=0, lwd=1.2, 
         angle=90, code=0 )
  points(i-1,means.es[i], pch=21,  cex=1.4,col="black", bg=colo2[i])
  text(i-1,  means.hi[i]+.02, cex=1.1, labels=let[i])
} 

mtext(expression("GLMM_2"), side = 3, line = -1.2, adj = 0.1, cex = .6, col = "black")  
mtext(expression(paste(italic (X)[2]^2, "=11.65, ", italic (P), "=0.0029")), side = 1, line = -1.2, adj =.9, cex = .6, col = "black")  


########################################################################################################
# Fig. 5.  Probability of yield decline in relation to pollinator dependence by geographical region.
########################################################################################################

glmm_3=glmmTMB(slope_bin  ~  dep*form + dep*region +form*region + lareap + lareac  +  (1|country) + (1|crop), data=data,family=binomial(link="logit"))
Anova(glmm_3)
summary(glmm_3)

par(mfrow = c(3, 2))
par(cex = 0.6)   #number indicating the amount by which plotting text and symbols 
par(oma = c(8,2 , 4, 2))  #internal margins, oma=external margins
par(tcl = -0.25)   #The length of tick marks as a fraction of the height of a line of text. 
par(mgp = c(3, 1, 0)) #The margin line (in mex units) for the axis title, axis labels 

colo1=c("yellow", "orange", "red")

meansxx<-lsmeans(glmm_3, ~ dep| region)
contrast(meansxx, alpha=0.05, method="pairwise", adjust="Tukey")
(meansxx=summary(meansxx))
(means.es=invlogit(meansxx[,3]))
(means.lo=invlogit(meansxx[,3]-meansxx[,4]))
(means.hi=invlogit(meansxx[,3]+meansxx[,4]))

#..........................................................
par(mar = c(4,4,1,0)) 
plot(1, axes = FALSE, type = "n", xlim=c(-0.5, 2.5), ylim=c(0.,.6), ylab="", xlab="")

box(col = "black") 
title(xlab="", cex.lab=1.3, line=3)
title(ylab="Probability of yield decline", cex.lab=1.3, line=3)
axis(1,  at = seq(0, 2, 1), labels = c("None", "Modest", "High"),
     cex.axis=1.1, tick = TRUE, las=1)
axis(2,  at = seq(0., .6, .05), labels = TRUE, tick = TRUE, las=2, cex.axis=1)

let=c("a", "a", "a")

for (i in 1:3)
{
  arrows(i-1, means.lo[i], i-1,  means.hi[i], length=0, lwd=1.2, 
         angle=90, code=0 )
  points(i-1,means.es[i], pch=21,  cex=1.4,col="black", bg=colo1[i])
  text(i-1,  means.hi[i]+.03, cex=1.1, labels=let[i])
} 

mtext(expression("Africa"), side = 3, line = -1.2, adj = 0.1, cex = .6, col = "black")  


#..........................................................
par(mar = c(4,4,1,0)) 
plot(2, axes = FALSE, type = "n", xlim=c(2.5, 5.5), ylim=c(0.0,.6), ylab="", xlab="")

box(col = "black") 
title(xlab="", cex.lab=1.3, line=3)
title(ylab="", cex.lab=1.3, line=3)
axis(1,  at = seq(3, 5, 1), labels = c("None", "Modest", "High"),
     cex.axis=1.1, tick = TRUE, las=1)
axis(2,  at = seq(0., .6, .05), labels = TRUE, tick = TRUE, las=2, cex.axis=1)

let=c("a", "a", "a")

for (i in 4:6)
{
  arrows(i-1, means.lo[i], i-1,  means.hi[i], length=0, lwd=1.2, 
         angle=90, code=0 )
  points(i-1,means.es[i], pch=21,  cex=1.4,col="black", bg=colo1[i-3])
  text(i-1,  means.hi[i]+.03, cex=1.1, labels=let[i-3])
} 

mtext(expression("Americas"), side = 3, line = -1.2, adj = 0.1, cex = .6, col = "black")  


#..........................................................
par(mar = c(4,4,1,0)) 
plot(3, axes = FALSE, type = "n", xlim=c(5.5, 8.5), ylim=c(0.0,.6), ylab="", xlab="")

box(col = "black") 
title(xlab="", cex.lab=1.3, line=3)
title(ylab="Probability of yield decline", cex.lab=1.3, line=3)
axis(1,  at = seq(6, 8, 1), labels = c("None", "Modest", "High"),
     cex.axis=1.1, tick = TRUE, las=1)
axis(2,  at = seq(0., .6, .05), labels = TRUE, tick = TRUE, las=2, cex.axis=1)

let=c("a", "b", "ab")


for (i in 7:9)
{
  arrows(i-1, means.lo[i], i-1,  means.hi[i], length=0, lwd=1.2, 
         angle=90, code=0 )
  points(i-1,means.es[i], pch=21,  cex=1.4,col="black", bg=colo1[i-6])
  text(i-1,  means.hi[i]+.03, cex=1.1, labels=let[i-6]) 
} 

mtext(expression("Asia"), side = 3, line = -1.2, adj = 0.1, cex = .6, col = "black")  

#..........................................................
par(mar = c(4,4,1,0)) 
plot(4, axes = FALSE, type = "n", xlim=c(8.5, 11.5), ylim=c(0.0,.6), ylab="", xlab="")

box(col = "black") 
title(xlab="Pollinator dependence", cex.lab=1.3, line=3)
title(ylab="", cex.lab=1.3, line=3)
axis(1,  at = seq(9, 11, 1), labels = c("None", "Modest", "High"),
     cex.axis=1.1, tick = TRUE, las=1)
axis(2,  at = seq(0., .6, .05), labels = TRUE, tick = TRUE, las=2, cex.axis=1)

let=c("a", "a", "a")


for (i in 10:12)
{
  arrows(i-1, means.lo[i], i-1,  means.hi[i], length=0, lwd=1.2, 
         angle=90, code=0 )
  points(i-1,means.es[i], pch=21,  cex=1.4,col="black", bg=colo1[i-9])
  text(i-1,  means.hi[i]+.03, cex=1.1, labels=let[i-9]) 
  
} 

mtext(expression("Europe"), side = 3, line = -1.2, adj = 0.1, cex = .6, col = "black")  

#..........................................................
par(mar = c(4,4,1,0)) 
plot(5, axes = FALSE, type = "n", xlim=c(11.5, 14.5), ylim=c(0.0,.6), ylab="", xlab="")
box(col = "black") 
title(xlab="Pollinator dependence", cex.lab=1.3, line=3)
title(ylab="Probability of yield decline", cex.lab=1.3, line=3)
axis(1,  at = seq(12, 14, 1), labels = c("None", "Modest", "High"),
     cex.axis=1.1, tick = TRUE, las=1)
axis(2,  at = seq(0., .6, .05), labels = TRUE, tick = TRUE, las=2, cex.axis=1)

let=c("a", "a", "a")


for (i in 13:15)
{
  arrows(i-1, means.lo[i], i-1,  means.hi[i], length=0, lwd=1.2, 
         angle=90, code=0 )
  points(i-1,means.es[i], pch=21,  cex=1.4,col="black", bg=colo1[i-12])
  text(i-1,  means.hi[i]+.03, cex=1.1, labels=let[i-12]) 
  
} 

mtext(expression("Oceania"), side = 3, line = -1.2, adj = 0.1, cex = .6, col = "black")  

########################################################################################################
# Fig. 6.  Probability of yield decline in relation to growth form by geographical region.
########################################################################################################

glmm_3=glmmTMB(slope_bin  ~  dep*form + dep*region +form*region + lareap + lareac  +  (1|country) + (1|crop), data=data,family=binomial(link="logit"))
Anova(glmm_3)
summary(glmm_3)

par(mfrow = c(3, 2))
par(cex = 0.6)   #number indicating the amount by which plotting text and symbols 
par(oma = c(8,2 , 4, 2))  #internal margins, oma=external margins
par(tcl = -0.25)   #The length of tick marks as a fraction of the height of a line of text. 
par(mgp = c(3, 1, 0)) #The margin line (in mex units) for the axis title, axis labels 

colo1=c("chartreuse1", "darkolivegreen", "brown")

meansxx<-lsmeans(glmm_3, ~ form| region)
contrast(meansxx, alpha=0.05, method="pairwise", adjust="Tukey")
(meansxx=summary(meansxx))
(means.es=invlogit(meansxx[,3]))
(means.lo=invlogit(meansxx[,3]-meansxx[,4]))
(means.hi=invlogit(meansxx[,3]+meansxx[,4]))

#..........................................................
par(mar = c(4,4,1,0)) 
plot(1, axes = FALSE, type = "n", xlim=c(-0.5, 2.5), ylim=c(0.,.6), ylab="", xlab="")
box(col = "black") 
title(xlab="", cex.lab=1.3, line=3)
title(ylab="Probability of yield decline", cex.lab=1.3, line=3)
axis(1,  at = seq(0, 2, 1), labels = c("Herb", "Shrub", "Tree"),
     cex.axis=1.1, tick = TRUE, las=1)
axis(2,  at = seq(0., .6, .05), labels = TRUE, tick = TRUE, las=2, cex.axis=1)

let=c("a", "a", "a")

for (i in 1:3)
{
  arrows(i-1, means.lo[i], i-1,  means.hi[i], length=0, lwd=1.2, 
         angle=90, code=0 )
  points(i-1,means.es[i], pch=21,  cex=1.4,col="black", bg=colo1[i])
  text(i-1,  means.hi[i]+.03, cex=1.1, labels=let[i]) 
} 

mtext(expression("Africa"), side = 3, line = -1.2, adj = 0.1, cex = .6, col = "black")  

#..........................................................
par(mar = c(4,4,1,0)) 
plot(2, axes = FALSE, type = "n", xlim=c(2.5, 5.5), ylim=c(0.0,.6), ylab="", xlab="")

box(col = "black") 
title(xlab="", cex.lab=1.3, line=3)
title(ylab="", cex.lab=1.3, line=3)
axis(1,  at = seq(3, 5, 1), labels = c("Herb", "Shrub", "Tree"),
     cex.axis=1.1, tick = TRUE, las=1)
axis(2,  at = seq(0., .6, .05), labels = TRUE, tick = TRUE, las=2, cex.axis=1)

let=c("a", "a", "a")

for (i in 4:6)
{
  arrows(i-1, means.lo[i], i-1,  means.hi[i], length=0, lwd=1.2, 
         angle=90, code=0 )
  points(i-1,means.es[i], pch=21,  cex=1.4,col="black", bg=colo1[i-3])
  text(i-1,  means.hi[i]+.03, cex=1.1, labels=let[i-3]) 
} 

mtext(expression("Americas"), side = 3, line = -1.2, adj = 0.1, cex = .6, col = "black")  

#..........................................................
par(mar = c(4,4,1,0)) 
plot(3, axes = FALSE, type = "n", xlim=c(5.5, 8.5), ylim=c(0.0,.6), ylab="", xlab="")

box(col = "black") 
title(xlab="", cex.lab=1.3, line=3)
title(ylab="Probability of yield decline", cex.lab=1.3, line=3)
axis(1,  at = seq(6, 8, 1), labels = c("Herb", "Shrub", "Tree"),
     cex.axis=1.1, tick = TRUE, las=1)
axis(2,  at = seq(0., .6, .05), labels = TRUE, tick = TRUE, las=2, cex.axis=1)

let=c("a", "a", "b")


for (i in 7:9)
{
  arrows(i-1, means.lo[i], i-1,  means.hi[i], length=0, lwd=1.2, 
         angle=90, code=0 )
  points(i-1,means.es[i], pch=21,  cex=1.4,col="black", bg=colo1[i-6])
  text(i-1,  means.hi[i]+.03, cex=1.1, labels=let[i-6]) 
} 

mtext(expression("Asia"), side = 3, line = -1.2, adj = 0.1, cex = .6, col = "black")  

#..........................................................
par(mar = c(4,4,1,0)) 
plot(4, axes = FALSE, type = "n", xlim=c(8.5, 11.5), ylim=c(0.0,.6), ylab="", xlab="")

box(col = "black") 
title(xlab="Growth form", cex.lab=1.3, line=3)
title(ylab="", cex.lab=1.3, line=3)
axis(1,  at = seq(9, 11, 1), labels = c("Herb", "Shrub", "Tree"),
     cex.axis=1.1, tick = TRUE, las=1)
axis(2,  at = seq(0., .6, .05), labels = TRUE, tick = TRUE, las=2, cex.axis=1)

let=c("a", "ab", "b")

for (i in 10:12)
{
  arrows(i-1, means.lo[i], i-1,  means.hi[i], length=0, lwd=1.2, 
         angle=90, code=0 )
  points(i-1,means.es[i], pch=21,  cex=1.4,col="black", bg=colo1[i-9])
  text(i-1,  means.hi[i]+.03, cex=1.1, labels=let[i-9]) #, pos=4)
} 

mtext(expression("Europe"), side = 3, line = -1.2, adj = 0.1, cex = .6, col = "black")  

#..........................................................
par(mar = c(4,4,1,0)) 
plot(5, axes = FALSE, type = "n", xlim=c(11.5, 14.5), ylim=c(0.0,.6), ylab="", xlab="")

box(col = "black") 
title(xlab="Growth form", cex.lab=1.3, line=3)
title(ylab="Probability of yield decline", cex.lab=1.3, line=3)
axis(1,  at = seq(12, 14, 1), labels = c("Herb", "Shrub", "Tree"),
     cex.axis=1.1, tick = TRUE, las=1)
axis(2,  at = seq(0., .6, .05), labels = TRUE, tick = TRUE, las=2, cex.axis=1)

let=c("a", "ab", "b")


for (i in 13:15)
{
  arrows(i-1, means.lo[i], i-1,  means.hi[i], length=0, lwd=1.2, 
         angle=90, code=0 )
  points(i-1,means.es[i], pch=21,  cex=1.4,col="black", bg=colo1[i-12])
  text(i-1,  means.hi[i]+.03, cex=1.1, labels=let[i-12])
} 

mtext(expression("Oceania"), side = 3, line = -1.2, adj = 0.1, cex = .6, col = "black")  

#######################################Supplementary Figures###################

########################################################################################################
# Fig. S1.  A randomly-chosen sample of yield trends (1961-2020) for different crops in different countries.  
########################################################################################################

data_basic = read.csv("FAOdata_21-12-2021.csv", sep = ",", header = T)[c(2, 4, 6, 8, 10)]
names(data_basic) = c("country", "crop", "vari", "year", "value")
data_basic = data_basic[data_basic$country != "China", ]   #Delete China because reported series are since 1991
data_basic$country[data_basic$country == "China, mainland"] = "China"  #"China, mainland"  includes the complete series

# Loading the country dataset
countries = data.frame(read.csv("countries.csv", sep = ",", header = T)[, c(1, 2)])
names(countries)=c("country", "region")  

# Loading the pollinator dependence dataset
dependence = read.csv("dependence.csv", sep = ",", header = T)

# Loading the traits dataset (others than pollinator dependence)
traits = data.frame(read.csv("traits.csv", sep = ",", header = T)[, c(1, 5, 6)])
names(traits)=c("crop", "organ", "form")


# Merging datasets
data_basic = merge(data_basic, countries, by.x = "country", by.y = "country")
data_basic = merge(data_basic, dependence, by.x = "crop", by.y = "crop")
data_basic = merge(data_basic, traits, by.x = "crop", by.y = "crop")


#Changing the format of the dataset from "long" to "wide" according to the variable reported by FAO (i.e., area, production, and yield)
library(reshape)
data=reshape(data_basic, direction="wide", timevar="vari",
             idvar=c("country", "region", "crop", "organ", "dep",  "form",  "year")) 

data=data[, c(2,4, 1, 5, 7, 6, 3, 8, 10, 9)]
names(data)=c("country","region","crop", "dep", "form","organ","year", 
              "yield","prod","area")    #production in tonnes, area in hectares, yield in hectograms/ha
data$dep=ifelse(data$dep==3 | data$dep==4, "high", ifelse(data$dep==0,"none", "moderate"))  # grouping pollinator dependences in three clases
data$dep<- factor(data$dep, levels = c( "none", "moderate", "high"))

#Excluding incomplete or 0 records
data=data[order(data$country, data$crop, data$year), ]
data=na.omit(data)
data=data[data$area>0,] #excluding records with area=0 
data=data[data$prod>0,] #excluding records with production=0 
data=data[data$yield>0,] #excluding records with yield=0 
nrow(data)


#Excluding incomplete data series (not encompassing the entire period 1961-2020)  
no_years=aggregate(data$yield, list(data$crop, data$country), length)
names(no_years)=c("crop", "country", "years")
data=merge(data, no_years, by.x = c("crop", "country"), by.y = c("crop", "country")) 
nrow(data)
data=data[data$years==60,]
data=data[,1:10]  #drop the colum years
rownames(data)=1:nrow(data)
data =data[!apply(is.na(data) | data == "", 1, all),]
nrow(data)

data=data[order(data$country, data$crop, data$year), ]
data$yield=log(data$yield)

data$color[data$dep=="high"]="red"
data$color[data$dep=="moderate"]="orange"
data$color[data$dep=="none"]="yellow"

split_data = split(data, list(data$country, data$crop))
length(split_data)
split_data=split_data[sapply(split_data, nrow)==60] 
length(split_data)
split_data=na.omit(split_data)
length(split_data)

set.seed=1235
x=sample(1:length(split_data),126)
split_yield=split_data[x]
length(split_yield)

mosaic=function(split_yield){
  par(mfrow = c(6, 3))
  par(cex = 0.6)   #number indicating the amount by which plotting text and symbols 
  par(mar = c(0,0,0,0), oma = c(5, 5, 2, 2))  #internal margins, oma=external margins
  par(tcl = -0.25)   #The length of tick marks as a fraction of the height of a line of text. 
  par(mgp = c(2, 0.6, 0)) #The margin line (in mex units) for the axis title, axis labels 

  for (i in 1:18) {
 
    plot(1, axes = FALSE, type = "n", xlim=c(1960, 2018), ylim=c(4, 16))
    
    if (i %in% c(16, 17, 18))
      axis(1, col = "grey40", col.axis = "grey20", at = seq(1961,2011, 10), las=2)
    if (i %in% c(1, 4, 7, 10, 13, 16))
      axis(2, col = "grey40", col.axis = "grey20", at = seq(4, 16, 2), las=2)
    box(col = "grey60") 
    
    fit= lm(split_yield[[i]]$yield ~ split_yield[[i]]$year)
    curve(coef(fit)[1] + coef(fit)[2]*x, add=TRUE, lty=1, col="green4", lwd=.8)
    
    points(split_yield[[i]]$year, split_yield[[i]]$yield, pch=21,  cex=.8,col=split_yield[[i]]$color, bg=split_yield[[i]]$color)
    
    fit= lm(split_yield[[i]]$yield ~ split_yield[[i]]$year)
    curve(coef(fit)[1] + coef(fit)[2]*x, add=TRUE, lty=1, col="green4", lwd=.8)
    smoothingSpline = smooth.spline(split_yield[[i]]$year, split_yield[[i]]$yield, spar=0.8)
    lines(smoothingSpline)
    mtext (split_yield[[i]]$crop[1] , side = 3, line = -1.1, adj = 0.1, cex = 0.5, col = "black") 
    mtext (split_yield[[i]]$country[1] , side = 3, line = -2.1, adj = 0.1, cex = 0.5, col = "black")
  }
  mtext("Year", side = 1, outer = TRUE, cex = .9, line = 3.2, col = "grey20")
  mtext("Ln(yield(kg/ha))", side = 2, outer = TRUE, cex = .9, line = 3.2, col = "grey20")
}

x=split_yield[1:18]
mosaic(x)

x=split_yield[19:36]
mosaic(x)

x=split_yield[37:54]
mosaic(x)

x=split_yield[55:72]
mosaic(x)

x=split_yield[73:90]
mosaic(x)

x=split_yield[91:108]
mosaic(x)

x=split_yield[109:126]
mosaic(x)

####################################################################
#Load data again to make the rest of the supplementary figures

data=read.csv("growth.csv", sep=",", header=T) #dataset that includes growth rates estimates
data$dep<- factor(data$dep, levels = c( "none", "moderate", "high"))
data$slope_bin=ifelse(data$slope<0, 1, 0) #Converting yield growth into a binary variable
#decline 1 non-decline 0
data$lareac=log10(data$areac)-mean(log10(data$areac))  #log transfomation and centering of cumulative cultivated area per crop
data$lareap=log10(data$areap)-mean(log10(data$areap))  #log transfomation and centering of cumulative cultivated area per country

#Required packages
library(glmmTMB)
library(lme4)
library(arm)
library(lsmeans)
library(car)

########################################################################################################
# Fig. S2.  Variation in the probability of yield decline among crops (to be sabed in A4 format).  
########################################################################################################

glmm_0=glmer(slope_bin ~ 1 +  (1|country) + (1|crop), data=data,  family=binomial)

x=coef(glmm_0)$crop
y=rownames(x)
z=se.ranef(glmm_0)$crop


dec_crop=data.frame(y, invlogit(x), invlogit(x-z), invlogit(x+z))
rownames(dec_crop)=1:nrow(dec_crop)
names(dec_crop)=c("crop", "dec", "nse", "pse")
xx=aggregate(data, list(data$crop, data$dep, data$form, data$organ), length)  [,1:5] #Create a file with just the names of crop and their traits
names(xx)=c("crop","dep", "form", "organ")
dec_crop=merge(dec_crop, xx, by.x = "crop", by.y = "crop") #Create a file with the incidence of decline per crop
dec_crop=dec_crop[order(dec_crop$dec),]
rownames(dec_crop)=1:nrow(dec_crop)

mean(dec_crop$dec)


par(cex = 0.6)   #number indicating the amount by which plotting text and symbols 
par(mar = c(0,3,0,0), oma = c(5, 8, 4, 10))  #internal margins, oma=external margins
par(tcl = -0.25)   #The length of tick marks as a fraction of the height of a line of text. 
par(mgp = c(2, 0.6, 0)) #The margin line (in mex units) for the axis title, axis labels 

plot(1, axes = FALSE, type = "n", xlim=c(0, .6), ylim=c(4,nrow(dec_crop)-3), ylab="", xlab="")
box(col = "black")
#abline(v=0, lty=2, lwd=.5)
points(dec_crop$dec, seq(1: nrow(dec_crop)), pch=3,  cex=1.1,col="black", bg="black")

for (i in 1:nrow(dec_crop)){
  arrows(dec_crop$nse[i], i,dec_crop$pse[i], i, length=0.05, angle=90, code=0)
}

axis(1, at = seq(0, .6, .1), labels = TRUE, tick = TRUE, cex.axis=1.2)
axis(2,  at = seq(1, nrow(dec_crop), 1), labels =dec_crop$crop, tick = TRUE, las=2, cex.axis=.6)

mtext("Probability of yield decline", side = 1, line = 3, adj = 0.5, cex =1.2, col = "black")
mtext("Crop", side = 2, line = 8.2, adj = 0.55, cex = 1.2, col = "black")


dec_crop$color[dec_crop$dep=="none"]="yellow"
dec_crop$color[dec_crop$dep=="moderate"]="orange"
dec_crop$color[dec_crop$dep=="high"]="red"
points(rep(-.015, nrow(dec_crop)), seq(1: nrow(dec_crop)), pch=22,  cex=1.2,col=dec_crop$color, bg=dec_crop$color)



dec_crop$color[dec_crop$form=="herb"]="chartreuse1"
dec_crop$color[dec_crop$form=="shrub"]="darkolivegreen"
dec_crop$color[dec_crop$form=="tree"]="brown"
points(rep(-.006, nrow(dec_crop)), seq(1: nrow(dec_crop)), pch=22,  cex=1.2,col=dec_crop$color, bg=dec_crop$color)


dec_crop$color[dec_crop$organ=="reproductive"]="blueviolet"
dec_crop$color[dec_crop$organ=="vegetative"]="darkkhaki"
points(rep(.003, nrow(dec_crop)), seq(1: nrow(dec_crop)), pch=22,  cex=1.2,col=dec_crop$color, bg=dec_crop$color)

legend(.38, 30.5, expression(bold( "Pollinator dependence")), bty="n", cex=1.1)

legend(.41, 28, c("None","Modest",  "High"),bty="n" ,pch=22,  cex=1.1,col=c("yellow", "orange", "red"),
       x.intersp = .8, y.intersp=.8,  pt.cex=1.1, pt.bg =c("yellow", "orange", "red"))

legend(.38, 20.5, expression(bold( "Growth form")), bty="n", cex=1.1)

legend(.41, 18, c("Herb","Shrub","Tree"),bty="n" ,pch=22,  cex=1.1,col=c("chartreuse1", "darkolivegreen", "brown"),
       x.intersp = .8, y.intersp=.8,  pt.cex=1.1, pt.bg =c("chartreuse1", "darkolivegreen", "brown"))

legend(.38, 10.5, expression(bold( "Organ consumed")), bty="n", cex=1.1)

legend(.41, 8, c("Vegetative", "Reproductive"),bty="n" ,pch=22,  cex=1.1,col=c("darkkhaki", "blueviolet"),
       x.intersp = .8, y.intersp=.8,  pt.cex=1.1, pt.bg =c("darkkhaki", "blueviolet"))


########################################################################################################
# Fig. S3.  Variation in the probability of yield decline among crops (to be sabed in A4 format).  
########################################################################################################

glmm_0=glmer(slope_bin ~ 1 +  (1|country) + (1|crop), data=data,  family=binomial)

x=coef(glmm_0)$country
y=rownames(x)
z=se.ranef(glmm_0)$country

dec_count=data.frame(y, invlogit(x), invlogit(x-z), invlogit(x+z))
rownames(dec_count)=1:nrow(dec_count)
names(dec_count)=c("country", "dec", "nse", "pse")
xx=aggregate(data, list(data$country, data$region), length) [,1:3]
names(xx)=c("country","region", "deve")
dec_count=merge(dec_count, xx, by.x = "country", by.y = "country")
dec_count=dec_count[order(dec_count$dec, decreasing=T),]
rownames(dec_count)=1:nrow(dec_count)

#data$ah=ifelse(data$form== "tree", 1, 0 )
xx=aggregate(data$slope_bin, list(data$country), function(x) sum(x)/length(x))
names(xx)=c("country", "prop")

dec_count=merge(xx, dec_count, by.x = "country", by.y = "country")
cor.test(dec_count$prop, dec_count$dec)

quantile(dec_count$dec, probs = c(.25,0.50,0.75))
dec_count=dec_count[order(dec_count$dec, decreasing=F),]

##########################################################################################
par(cex = 0.6)   #number indicating the amount by which plotting text and symbols 
par(mar = c(0,3,0,0), oma = c(5, 10, 4, 8))  #internal margins, oma=external margins
par(tcl = -0.25)   #The length of tick marks as a fraction of the height of a line of text. 
par(mgp = c(2, 0.6, 0)) #The margin line (in mex units) for the axis title, axis labels 

plot(1, axes = FALSE, type = "n", xlim=c(0, .8), ylim=c(4,nrow(dec_count)-3), ylab="", xlab="")
box(col = "black")
points(dec_count$dec, seq(1: nrow(dec_count)), pch=3,  cex=1.1,col="black", bg="black")


for (i in 1:nrow(dec_count)){
  arrows(dec_count$nse[i], i,dec_count$pse[i], i, length=0.05, angle=90, code=0)
}

axis(1, at = seq(0, .8, .1), labels = TRUE, tick = TRUE, cex.axis=1.2)
axis(2,  at = seq(1, nrow(dec_count), 1), labels =dec_count$country, tick = TRUE, las=2, cex.axis=.6)

mtext("Probability of yield decline", side = 1, line = 3, adj = 0.5, cex =1.2, col = "black")
mtext("Country", side = 2, line = 8.2, adj = 0.55, cex = 1.2, col = "black") 

dec_count$color[dec_count$region=="Africa"]="darkgrey"
dec_count$color[dec_count$region=="Americas"]="red"
dec_count$color[dec_count$region=="Asia"]="yellow"
dec_count$color[dec_count$region=="Europe"]="blue"
dec_count$color[dec_count$region=="Oceania"]="green"
points(rep(-.024, nrow(dec_count)), seq(1: nrow(dec_count)), pch=22,  cex=.9,col=dec_count$color, bg=dec_count$color)

legend(.52, 21.5, expression(bold( "Region")), bty="n", cex=1.1)

legend(.55, 19, c("Africa","Americas","Asia", "Europe", "Oceania"),bty="n" ,pch=22,  cex=1.1,
       col=c("darkgrey", "red", "yellow", "blue", "green"),
       x.intersp = .8, y.intersp=.8,  pt.cex=1.1, pt.bg =c("darkgrey", "red", "yellow", "blue", "green"))


########################################################################################################
# Fig. S4. Probability of yield decline by geographical region as estimated by the main effects models.  
########################################################################################################

glmm_1a=glmmTMB(slope_bin  ~   dep + region +   lareap + lareac  +  (1|country) + (1|crop), data=data,family=binomial(link="logit"))
Anova(glmm_1a)
glmm_1b=glmmTMB(slope_bin  ~   form + region +   lareap + lareac  +  (1|country) + (1|crop), data=data,family=binomial(link="logit"))
Anova(glmm_1b)
glmm_2 =glmmTMB(slope_bin  ~  dep +  form + region + lareap + lareac  +  (1|country) + (1|crop), data=data,family=binomial(link="logit"))
Anova(glmm_2)

par(mfrow = c(2, 2))
par(cex = 0.6)   #number indicating the amount by which plotting text and symbols 
par(oma = c(8,2 , 4, 2))  #internal margins, oma=external margins
par(tcl = -0.25)   #The length of tick marks as a fraction of the height of a line of text. 
par(mgp = c(3, 1, 0)) #The margin line (in mex units) for the axis title, axis labels 

colo=c("darkgrey", "red", "yellow", "blue", "green")

...................................
par(mar = c(4,4,6,1)) 
plot(1, axes = FALSE, type = "n", xlim=c(-0.5, 4.5), ylim=c(0.1,.4), ylab="", xlab="")

box(col = "black") 
title(xlab="", cex.lab=1.3, line=3)
title(ylab="Probability of yield decline", cex.lab=1.3, line=3)
axis(1,  at = seq(0, 4, 1), labels = c("AF","AM", "AS", "EU","OC"),
     cex.axis=1.1, tick = TRUE, las=1)
axis(2,  at = seq(0.1, .4, .05), labels = TRUE, tick = TRUE, las=2, cex.axis=1)


meansxx<-lsmeans(glmm_1a, ~ region)
contrast(meansxx, alpha=0.05, method="pairwise", adjust="Tukey")
let=c("a", "ab", "b",  "b", "a")
(meansxx=summary(meansxx))
(means.es=invlogit(meansxx[,2]))
(means.lo=invlogit(meansxx[,2]-meansxx[,3]))
(means.hi=invlogit(meansxx[,2]+meansxx[,3]))


for (i in 1:5)
{
  arrows(i-1, means.lo[i], i-1,  means.hi[i], length=0, lwd=1.2, 
         angle=90, code=0 )
  points(i-1,means.es[i], pch=21,  cex=1.4,col="black", bg=colo[i])
  text(i-1,  means.hi[i]+.02, cex=1.1, labels=let[i]) #, pos=4)
  
} 

mtext(expression("GLMM_1a"), side = 3, line = -1.2, adj = 0.1, cex = .6, col = "black")  
mtext(expression(paste(italic (X)[4]^2, "=26.38, ", italic (P), "<0.0001")), side = 1, line = -1.2, adj =.1, cex = .6, col = "black")  

#..........................................................
par(mar = c(4,4,6,1)) 
plot(2, axes = FALSE, type = "n", xlim=c(-0.5, 4.5), ylim=c(0.1,.4), ylab="", xlab="")

box(col = "black")
title(xlab="Geographical region", cex.lab=1.3, line=3)
title(ylab="", cex.lab=1.3, line=3)


axis(1,  at = seq(0, 4, 1), labels = c("AF","AM", "AS", "EU","OC"),
     cex.axis=1.1, tick = TRUE, las=1)
axis(2,  at = seq(0.1, .4, .05), labels = TRUE, tick = TRUE, las=2, cex.axis=1)


meansxx<-lsmeans(glmm_1b, ~ region)
contrast(meansxx, alpha=0.05, method="pairwise", adjust="Tukey")
let=c("a", "ab", "b",  "b", "a")
(meansxx=summary(meansxx))
(means.es=invlogit(meansxx[,2]))
(means.lo=invlogit(meansxx[,2]-meansxx[,3]))
(means.hi=invlogit(meansxx[,2]+meansxx[,3]))


for (i in 1:5)
{
  arrows(i-1, means.lo[i], i-1,  means.hi[i], length=0, lwd=1.2, 
         angle=90, code=0 )
  points(i-1,means.es[i], pch=21,  cex=1.4,col="black", bg=colo[i])
  text(i-1,  means.hi[i]+.02, cex=1.1, labels=let[i]) #, pos=4)
  
} 

mtext(expression("GLMM_1b"), side = 3, line = -1.2, adj = 0.1, cex = .6, col = "black")  
mtext(expression(paste(italic (X)[4]^2, "=26.16, ", italic (P), "<0.0001")), side = 1, line = -1.2, adj =.1, cex = .6, col = "black")  

#..........................................................
par(mar = c(7,4,3,1)) 
plot(3, axes = FALSE, type = "n", xlim=c(-0.5, 4.5), ylim=c(0.1,.4), ylab="", xlab="")

box(col = "black") 
title(xlab="Geographical region", cex.lab=1.3, line=3)
title(ylab="Probability of yield decline", cex.lab=1.3, line=3)
axis(1,  at = seq(0, 4, 1), labels = c("AF","AM", "AS", "EU","OC"),
     cex.axis=1.1, tick = TRUE, las=1)
axis(2,  at = seq(0.1, .4, .05), labels = TRUE, tick = TRUE, las=2, cex.axis=1)


meansxx<-lsmeans(glmm_2, ~ region)
contrast(meansxx, alpha=0.05, method="pairwise", adjust="Tukey")
let=c("a", "ab", "b",  "b", "a")
(meansxx=summary(meansxx))
(means.es=invlogit(meansxx[,2]))
(means.lo=invlogit(meansxx[,2]-meansxx[,3]))
(means.hi=invlogit(meansxx[,2]+meansxx[,3]))

for (i in 1:5)
{
  arrows(i-1, means.lo[i], i-1,  means.hi[i], length=0, lwd=1.2, 
         angle=90, code=0 )
  points(i-1,means.es[i], pch=21,  cex=1.4,col="black", bg=colo[i])
  text(i-1,  means.hi[i]+.02, cex=1.1, labels=let[i]) #, pos=4)
  
} 

mtext(expression("GLMM_2"), side = 3, line = -1.2, adj = 0.1, cex = .6, col = "black")  
mtext(expression(paste(italic (X)[4]^2, "=26.40, ", italic (P), "<0.0001")), side = 1, line = -1.2, adj =.1, cex = .6, col = "black")  



########################################################################################################
# Fig. S5. Probability of yield decline and cumulative cultivated area per crop and country.  
########################################################################################################


glmm_2 =glmer(slope_bin  ~  dep +  form + region + lareap + lareac  +  (1|country) + (1|crop), data=data,family=binomial(link="logit"))
Anova(glmm_2)


inter=fixef(glmm_2)[1]  #intercept
bareac=fixef(glmm_2)[11] #slope x crop
bareap=fixef(glmm_2)[10] #slope x country


#creo archivo de crop x area
colod=ifelse(data$dep=="none", "yellow", ifelse(data$dep=="moderate", "orange", "red"))
colof=ifelse(data$form=="herb", "chartreuse1", ifelse(data$form=="shrub", "darkolivegreen", "brown"))

clareac=data$lareac+mean(log10(data$areac))
crop=unique(data.frame(data$crop,data$lareac, clareac, data$dep, data$form, colod, colof))
names(crop)=c("crop", "lareac", "clareac", "dep", "form", "colod", "colof")


crop$pred=inter+ bareac*crop$lareac
crop=crop[order(crop$crop),]

r.crop=data.frame(ranef(glmm_2)$crop, se.ranef(glmm_2)$crop)
names(r.crop)=c("resid", "se")

crop=cbind(crop, r.crop)
crop$corre=crop$pred+crop$resid

crop=crop[,c(1,3, 8,11, 10, 4:7)]

# creo archivo de crop por country
data$color[data$region=="Africa"]="darkgrey"
data$color[data$region=="Americas"]="red"
data$color[data$region=="Asia"]="yellow"
data$color[data$region=="Europe"]="blue"
data$color[data$region=="Oceania"]="green"

clareap=data$lareap+mean(log10(data$areap))
country=unique(data.frame(data$country,data$lareap, clareap, data$region, data$color))
names(country)=c("country", "lareap", "clareap", "region", "color")


country$pred=inter+ bareap*country$lareap
country=country[order(country$country),]

r.country=data.frame(ranef(glmm_2)$country, se.ranef(glmm_2)$country)
names(r.country)=c("resid", "se")

country=cbind(country, r.country)
country$corre=country$pred+country$resid

head(country)

country=country[,c(1,3, 6,9, 8, 4:5)]



par(mfrow = c(2, 2))
par(cex = 0.6)   #number indicating the amount by which plotting text and symbols 
#should be scaled relative to the default. 1=default, 1.5 is 50% larger, 0.5 is 50% smaller, etc.
par(oma = c(8,2 , 4, 2))  #internal margins, oma=external margins
par(tcl = -0.25)   #The length of tick marks as a fraction of the height of a line of text. 
#The default value is -0.5; setting tcl = NA sets tck = -0.01 which is S' default
par(mgp = c(3, 1, 0)) #The margin line (in mex units) for the axis title, axis labels 
#and axis line. Note that mgp[1] affects title whereas mgp[2:3] affect axis. The default is c(3, 1, 0).

#...................................


par(mar = c(4,4,7,1)) 
plot(1, axes = FALSE, type = "n", xlim=c(4, 10), ylim=c(0,.85), ylab="", xlab="")

box(col = "black") 
title(xlab=expression("Area (" ~km^2~")" ),  cex.lab=1.5, line=3)
title(ylab="Probability of yield decline", cex.lab=1.5, line=3)
axis(1,  at = seq(4, 10, 1), labels=c(expression( 10^4,10^5,10^6,10^7, 10^8,10^9,10^10)),
     cex.axis=1.2, tick = TRUE, las=1)
axis(2,  at = seq(0., .8, .1), labels = TRUE, tick = TRUE, las=2, cex.axis=1.2)

cm=invlogit(crop$corre)
clo=invlogit(crop$corre-crop$se)
chi=invlogit(crop$corre+crop$se)

curve(invlogit(inter-mean(log10(data$areac))*bareac+ bareac*x), add=T,  lty=1, col="black", lwd=1.8, 
      xlim=c(min(crop$clareac), max(crop$clareac)))
arrows(crop$clareac, clo, crop$clareac,  chi, length=0, lwd=.5, angle=90, code=0, col="black")
points(crop$clareac, cm, pch=21,  cex=1.4,col="black", bg=crop$colod)
#text(i-1,  means.hi[i]+.02, cex=1.1, labels=let[i]) #, pos=4)


#legend(.38, 30.5, expression(bold( "Pollinator dependence")), bty="n", cex=1.1)

legend("topright", c("None","Modest",  "High"),bty="n" ,pch=21,  cex=1.1,col="black",
       x.intersp = .8, y.intersp=.8,  pt.cex=1.1, pt.bg =c("yellow", "orange", "red")) 
#       title=expression(bold( "Pollinator dependence")))

mtext(expression (bold("Crop (by pollinator dependence)")), side = 3, line = 1, adj = 0.1, cex = 1, col = "black")
mtext(expression(paste(italic (X)[1]^2, "=34.70, ", italic (P), "<0.0001")), side = 1, line = -1.2, adj =.1, cex = .8, col = "black")  


#...................................


par(mar = c(4,4,7,1)) 
plot(2, axes = FALSE, type = "n", xlim=c(4, 10), ylim=c(0,.85), ylab="", xlab="")

box(col = "black") 
title(xlab=expression("Area (" ~km^2~")" ),  cex.lab=1.5, line=3)
title(ylab="", cex.lab=1.5, line=3)
axis(1,  at = seq(4, 10, 1), labels=c(expression(  10^4,10^5,10^6,10^7, 10^8,10^9,10^10)),
     cex.axis=1.2, tick = TRUE, las=1)
axis(2,  at = seq(0., .8, .1), labels = TRUE, tick = TRUE, las=2, cex.axis=1.2)

cm=invlogit(crop$corre)
clo=invlogit(crop$corre-crop$se)
chi=invlogit(crop$corre+crop$se)

curve(invlogit(inter-mean(log10(data$areac))*bareac+ bareac*x), add=T,  lty=1, col="black", lwd=1.8,  
      xlim=c(min(crop$clareac), max(crop$clareac)))
arrows(crop$clareac, clo, crop$clareac,  chi, length=0, lwd=.5, angle=90, code=0, col="black")
points(crop$clareac, cm, pch=21,  cex=1.4,col="black", bg=crop$colof)
#text(i-1,  means.hi[i]+.02, cex=1.1, labels=let[i]) #, pos=4)


#legend(.38, 30.5, expression(bold( "Pollinator dependence")), bty="n", cex=1.1)

legend("topright", c("Herb","Shrub","Tree"),bty="n" ,pch=21,  cex=1.1,col="black",
       x.intersp = .8, y.intersp=.8,  pt.cex=1.1, pt.bg =c("chartreuse1", "darkolivegreen", "brown")) 
#       title=expression(bold( "Pollinator dependence")))

mtext(expression(bold("Crop (by growth from)")), side = 3, line = 1, adj = 0.1, cex = 1, col = "black")
mtext(expression(paste(italic (X)[1]^2, "=34.70, ", italic (P), "<0.0001")), side = 1, line = -1.2, adj =.1, cex = .8, col = "black")  


#...................................


par(mar = c(7,4,4,1)) 
plot(3, axes = FALSE, type = "n", xlim=c(3, 10), ylim=c(0,.85), ylab="", xlab="")

box(col = "black") 
title(xlab=expression("Area (" ~km^2~")" ),  cex.lab=1.5, line=3)
title(ylab="Probability of yield decline", cex.lab=1.5, line=3)
axis(1,  at = seq(3, 10, 1), labels=c(expression(10^3, 10^4,10^5,10^6,10^7, 10^8,10^9,10^10)),
     cex.axis=1.2, tick = TRUE, las=1)
axis(2,  at = seq(0., .8, .1), labels = TRUE, tick = TRUE, las=2, cex.axis=1.2)

cm=invlogit(country$corre)
clo=invlogit(country$corre-country$se)
chi=invlogit(country$corre+country$se)

curve(invlogit(inter-mean(log10(data$areap))*bareap+ bareap*x), add=T,  lty=1, col="black", lwd=1.8, 
      xlim=c(min(country$clareap), max(country$clareap)))
arrows(country$clareap, clo, country$clareap,  chi, length=0, lwd=.5, angle=90, code=0, col="black")
points(country$clareap, cm, pch=21,  cex=1.4,col="black", bg=country$color)
#text(i-1,  means.hi[i]+.02, cex=1.1, labels=let[i]) #, pos=4)


#legend(.38, 30.5, expression(bold( "Pollinator dependence")), bty="n", cex=1.1)

legend("topright", c("Africa", "Americas", "Asia", "Europe", "Oceania" ),bty="n" ,pch=21,  cex=1.1,col="black",
       x.intersp = .8, y.intersp=.8,  pt.cex=1.1, pt.bg =c("darkgrey", "red", "yellow", "blue","green")) 
#       title=expression(bold( "Pollinator dependence")))


mtext(expression(bold("Country (by region)")), side = 3, line = 1, adj = 0.1, cex = 1, col = "black")
mtext(expression(paste(italic (X)[1]^2, "=26.00, ", italic (P), "<0.0001")), side = 1, line = -1.2, adj =.1, cex = .8, col = "black")  

###########################################################

###########################################################